# Generated by Django 3.2.12 on 2022-02-21 15:01

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('drfr_test_app', '0001_initial'),
    ]

    operations = [
        migrations.AlterField(
            model_name='exampleitem',
            name='id',
            field=models.BigAutoField(
                auto_created=True, primary_key=True, serialize=False, verbose_name='ID'
            ),
        ),
        migrations.AlterField(
            model_name='examplem2mitem',
            name='id',
            field=models.BigAutoField(
                auto_created=True, primary_key=True, serialize=False, verbose_name='ID'
            ),
        ),
        migrations.AlterField(
            model_name='examplesubitem',
            name='id',
            field=models.BigAutoField(
                auto_created=True, primary_key=True, serialize=False, verbose_name='ID'
            ),
        ),
    ]
